import React, {useEffect, useState} from 'react';
import {getArtists} from '../features/artist/artistSlice';
import {useAppDispatch, useAppSelector} from '../store/hooks';
import {useNavigate} from 'react-router-dom';
import Preloader from '../components/UI/Preloader';

const HomePage: React.FunctionComponent = (): React.ReactElement => {
	const {loading, artists} = useAppSelector((state) => state.artist);
	const {userRole} = useAppSelector((state) => state.user);

	const dispatch = useAppDispatch();
	const navigate = useNavigate();

	useEffect(() => {
		dispatch(getArtists());
	}, [dispatch, navigate, userRole]);

	return (
		<div>
			<h2 className="mt-0 mb-2 text-4xl font-medium leading-tight ">Artists</h2>
			<div className="flex flex-wrap gap-10 justify-between ">
				{loading ? (
					<Preloader />
				) : artists.length ? (
					artists.map((artist) => {
						return (
							<div key={artist._id}>
								{userRole === 'Admin' ? (
									<>
										<img
											onClick={() =>
												navigate(
													{
														pathname: '/albums',
														search: `?artist=${artist._id}`,
													},
													{state: {artist: artist.name}}
												)
											}
											className="w-56 h-56 object-cover "
											src={`${import.meta.env.VITE_MY_URL}/${artist.photo}`}
											alt={artist.name}
										/>
										<span className="block">{artist.name}</span>
										{!artist.published && <p>Unpublished</p>}
										{artist.published ? (
											<button>Delete</button>
										) : (
											<button>Publish</button>
										)}
									</>
								) : artist.published ? (
									<>
										<img
											onClick={() =>
												navigate(
													{
														pathname: '/albums',
														search: `?artist=${artist._id}`,
													},
													{state: {artist: artist.name}}
												)
											}
											className="w-56 h-56 object-cover "
											src={`${import.meta.env.VITE_MY_URL}/${artist.photo}`}
											alt={artist.name}
										/>
										<span className="block">{artist.name}</span>
										<button>Delete</button>
									</>
								) : null}
							</div>
						);
					})
				) : (
					<p>No Artist yet</p>
				)}
			</div>
		</div>
	);
};

export default HomePage;
