import {createAsyncThunk, createSlice} from '@reduxjs/toolkit';
import type {PayloadAction} from '@reduxjs/toolkit';
import {RootState} from '../../store/store';
import IArtist from '../../interfaces/IArtist';
import {artistApi} from '../../api/artistApi';
import axios from 'axios';

interface ArtistState {
	artists: IArtist[];
	loading: boolean;
	unpublishedArtists: IArtist[];
}

const initialState: ArtistState = {
	artists: [],
	loading: false,
	unpublishedArtists: [],
};

export const getArtists = createAsyncThunk('getArtists', async () => {
	return await artistApi.get();
});

export const addArtist = createAsyncThunk(
	'addArtist',
	async (newArtist: FormData) => {
		const response = await axios({
			method: 'post',
			url: `${import.meta.env.VITE_MY_URL}/artists`,
			data: newArtist,
			headers: {
				'Content-Type': `multipart/form-data; `,
			},
		});
		return response.data;
	}
);

export const artistSlice = createSlice({
	name: 'artist',
	initialState,
	reducers: {},
	extraReducers: (builder) => {
		builder
			.addCase(getArtists.pending, (state, action) => {
				state.loading = true;
			})
			.addCase(getArtists.rejected, (state, action) => {
				state.loading = false;
			})
			.addCase(
				getArtists.fulfilled,
				(state, {payload}: PayloadAction<IArtist[]>) => {
					state.artists = payload;
					state.loading = false;
				}
			)
			.addCase(addArtist.pending, (state, action) => {
				state.loading = true;
			})
			.addCase(addArtist.rejected, (state, action) => {
				state.loading = false;
			})
			.addCase(addArtist.fulfilled, (state, action) => {
				state.loading = false;
				console.log(action.payload);
			});
	},
});

export const {} = artistSlice.actions;

export const selectArtists = (state: RootState) => state.artist.artists;

export default artistSlice.reducer;
